aboutsummaryrefslogtreecommitdiffhomepage
path: root/ccc
diff options
context:
space:
mode:
authorGravatar cxl <>2004-04-15 21:48:07 +0000
committerGravatar cxl <>2004-04-15 21:48:07 +0000
commitc39ae5296c474c17ef393279d84715cf7c357f5c (patch)
tree235577afeb0512f7983dcce867ba36cc6ad05870 /ccc
parentd26b22537d99d7761c64c0d1a1358c7f39eda995 (diff)
Added some syntax stuff (highlight comments etc).
Diffstat (limited to 'ccc')
-rw-r--r--ccc/ccc.el25
1 files changed, 24 insertions, 1 deletions
diff --git a/ccc/ccc.el b/ccc/ccc.el
index d997a757..81754b00 100644
--- a/ccc/ccc.el
+++ b/ccc/ccc.el
@@ -45,8 +45,31 @@
proof-count-undos-fn 'ccc-count-undos
;;
;; Some basic fontlocking, as taken from the hol98 instance.
;;
+ proof-script-syntax-table-entries
+ '(?\` "\""
+ ?\$ "."
+ ?\/ "."
+ ?\\ "."
+ ?+ "."
+ ?- "."
+ ?= "."
+ ?% "."
+ ?< "."
+ ?> "."
+ ?\& "."
+ ?. "w"
+ ?_ "w"
+ ?\' "w"
+ ?\| "."
+ ?\[ "(]"
+ ?\] ")["
+ ?\* ". 23"
+ ?\( "()1"
+ ?\) ")(4")
+
ccc-keywords '("use" "ap" "holcasl" "ccc" "load_lib" "qeccc")
ccc-tactics '("compose" "compose'" "prove" "prove_free_type")
ccc-tacticals '("Repeat" "Orelse" "Then" "ThenList" "OrelseList")
@@ -45,8 +45,31 @@
proof-count-undos-fn 'ccc-count-undos
;;
- ;; Some basic fontlocking, as taken from the hol98 instance.
+ ;; Some basic fontlocking and syntax table entries, as taken from the
+ ;; hol98 instance (it's all SML anyway :-)
;;